@@ -1,4 +1,4 @@
-from commonutils import StaticUtils
+from commonutils import Global, StaticUtils
 from os import sys, path
 from tkinter import Tk
 from tkinter.ttk import Notebook, Style
@@ -49,6 +49,8 @@ class AppLauncher:
       
       self.__notebook.place(relwidth = 1, relheight = 1)
       
+      Global.appLauncher = self
+      
       self.__root.mainloop()
    
    def _configureRoot(self):
