@@ -1,5 +1,5 @@
 from tkinter.ttk import LabelFrame
-from .basecontainer import BaseContainer
+from . import BaseContainer
 
 class LabeledContainer(BaseContainer, LabelFrame):
    _DEFAULT_STYLE = BaseContainer._defaultStyle()
